class Map(dict):
    __getattr__ = dict.get
    __setattr__ = dict.__setitem__
    __delattr__ = dict.__delitem__

    @staticmethod
    def create_recursively(data: dict) -> 'Map':
        data = Map(data)

        for key, value in data.items():
            if isinstance(value, dict):
                data[key] = Map.create_recursively(value)

        return data



from gics.definitions import d_20140228, d_20160901, d_20180929
from gics.map import Map

DEFINITIONS = {
    "20140228": d_20140228,
    "20160901": d_20160901,
    "20180929": d_20180929,
}

DEFAULT_VERSION = '20180929'


class GICS:

    def __init__(self, code: str = None, version: str = DEFAULT_VERSION):
        """Represents a GICS code. You can instantiate GICS codes using a string representing a code.
        The string has to be a valid GICS. If it's not, that is_valid method will return false.

        Note:
            that creating an empty GICS will mark it as invalid but can still be used to query the definitions
            (although that object itself will not be a definition)

        Args:
         code (str): GICS code to parse. Valid GICS codes are strings 2 to 8 characters long, with even length.
         version (str):

        Raises:
            ValueError: When given an invalid version
        """
        self._definition_version = version
        _definition = DEFINITIONS.get(self._definition_version)

        if not _definition:
            raise ValueError(f'Unsupported GICS version: {version}. Available versions are {list(DEFINITIONS.keys())}')

        self._definition = Map.create_recursively(_definition)

        self._code = code

        if self.is_valid:
            self._levels = [
                self._get_definition(code[:2]),
                self._get_definition(code[:4]) if len(code) >= 4 else None,
                self._get_definition(code[:6]) if len(code) >= 6 else None,
                self._get_definition(code[:8]) if len(code) == 8 else None
            ]
        else:
            self._code = None

    @property
    def definition(self):
        return self._definition

    @property
    def is_valid(self) -> bool:
        return self.code and isinstance(self.code, str) and len(self.code) >= 2 and len(self.code) <= 8 and len(
            self.code) % 2 == 0 and self._definition.get(self.code)

    @property
    def code(self):
        return self._code

    @property
    def sector(self):
        """Gets the definition for the sector of this GICS object (GICS level 1)

        Returns:
            Definition of the GICS level. It has 3 properties: name, description and code.
            Keep in mind that only level 4 usually has a description.
        """
        return self.level(1)

    @property
    def industry_group(self):
        """Gets the definition for the industry group of this GICS object (GICS level 2)

        Returns:
            Definition of the GICS level. It has 3 properties: name, description and code.
            Keep in mind that only level 4 usually has a description.
        """
        return self.level(2)

    @property
    def industry(self):
        """Gets the definition for the industry of this GICS object (GICS level 3)

        Returns:
            Definition of the GICS level. It has 3 properties: name, description and code.
            Keep in mind that only level 4 usually has a description.
        """
        return self.level(3)

    @property
    def sub_industry(self):
        """Gets the definition for the sub-industry of this GICS object (GICS level 4)

        Returns:
            Definition of the GICS level. It has 3 properties: name, description and code.
            Keep in mind that only level 4 usually has a description.
        """
        return self.level(4)

    @property
    def children(self):
        """Gets all the child level elements from this GICS level.
        For example, for a Sector level GICS, it will return all Industry Groups in that Sector.
        If the GICS is invalid (or empty, as with a null code), it will return all Sectors.
        A Sub-industry level GICS will return an empty array.

        Returns:
            List containing objects with properties code (the GICS code), name (the name of this GICS),
            and description (where applicable)
        """
        if self.is_valid:
            keys = filter(lambda k: k.startswith(self._code) and len(k) == len(self._code) + 2, self._definition.keys())
        else:
            keys = filter(lambda k: len(k) == 2, self._definition.keys())

        return list(map(lambda k: Map({
            'code': k,
            'name': self._definition[k].name,
            'description': self._definition[k].description
        }), keys))

    def _get_definition(self, gics_code):
        definition = self._definition[gics_code]
        definition.code = gics_code

        return definition

    def level(self, gics_level: int):
        """Gets the definition of the given level for this GICS object.

        Args:
            gics_level: Level of GICS to get.
                Valid levels are: 1 (Sector), 2 (Industry Group), 3 (Industry), 4 (Sub-Industry)

        Returns:

        """
        if not self.is_valid or not gics_level or not isinstance(gics_level,
                                                                 int) or gics_level < 1 or gics_level > 4:
            return None

        return self._levels[gics_level - 1]

    def is_same(self, another_gics: 'GICS') -> bool:
        """Determines if this GICS is the same as the given one.
        To be considered the same both GICS must either be invalid, or be valid and with the exact same code.
        This means that they represent the same values at the same level.

        Args:
            another_gics: GICS object to compare with
        """
        return another_gics and (self.is_valid == another_gics.is_valid) and (
                self.is_valid is False or self._code == another_gics.code)

    def is_within(self, another_gics: 'GICS'):
        """Determines if this GICS is a sub-component of the given GICS. For example, GICS 101010 is within GICS 10.
        Invalid GICS do not contain any children or belong to any parent, so if any of the GICS are invalid,
        this will always be false.
        Two GICS that are the same are not considered to be within one another (10 does not contain 10).

        Args:
            another_gics: GICS object to compare with
        """
        return self.is_valid and another_gics.is_valid and self._code != another_gics.code and self._code.startswith(
            another_gics.code)

    def is_immediate_within(self, another_gics: 'GICS'):
        """Determines if this GICS is a sub-component of the given GICS at the most immediate level. For example, GICS
        1010 is immediate within GICS 10, but 101010 is not.
        Invalid GICS do not contain any children or belong to any parent, so if any of the GICS are invalid,
        this will always be false.
        Two GICS that are the same are not considered to be within one another (10 does not contain 10).

        Args:
            another_gics: GICS object to compare with
        """
        return self.is_valid and another_gics.is_valid and self._code != another_gics.code and self._code.startswith(
            another_gics.code) and len(self._code) == len(another_gics._code) + 2

    def contains(self, another_gics: 'GICS'):
        """Determines if this GICS contains the given GICS. For example, GICS 10 contains GICS 101010.
        Invalid GICS do not contain any children or belong to any parent, so if any of the GICS are invalid,
        this will always be false.
        Two GICS that are the same are not considered to be within one another (10 does not contain 10).

        Args:
            another_gics: GICS object to compare with
        """
        return another_gics.is_within(self)

    def contains_immediate(self, another_gics: 'GICS'):
        """Determines if this GICS contains the given GICS at the most immediate level. For example, GICS 10 contains immediate GICS 1010, but not 101010.
        Invalid GICS do not contain any children or belong to any parent, so if any of the GICS are invalid, this will always be false.
        Two GICS that are the same are not considered to be within one another (10 does not contain 10).

        Args:
            another_gics: GICS object to compare with
        """
        return another_gics.is_immediate_within(self)



definition = {
    "10": {
        "name": "Energy"
    },
    "15": {
        "name": "Materials"
    },
    "20": {
        "name": "Industrials"
    },
    "25": {
        "name": "Consumer Discretionary"
    },
    "30": {
        "name": "Consumer Staples"
    },
    "35": {
        "name": "Health Care"
    },
    "40": {
        "name": "Financials"
    },
    "45": {
        "name": "Information Technology"
    },
    "50": {
        "name": "Telecommunication Services"
    },
    "55": {
        "name": "Utilities"
    },
    "1010": {
        "name": "Energy"
    },
    "1510": {
        "name": "Materials"
    },
    "2010": {
        "name": "Capital Goods"
    },
    "2020": {
        "name": "Commercial & Professional Services"
    },
    "2030": {
        "name": "Transportation"
    },
    "2510": {
        "name": "Automobiles & Components"
    },
    "2520": {
        "name": "Consumer Durables & Apparel"
    },
    "2530": {
        "name": "Consumer Services"
    },
    "2540": {
        "name": "Media"
    },
    "2550": {
        "name": "Retailing"
    },
    "3010": {
        "name": "Food & Staples Retailing"
    },
    "3020": {
        "name": "Food, Beverage & Tobacco"
    },
    "3030": {
        "name": "Household & Personal Products"
    },
    "3510": {
        "name": "Health Care Equipment & Services"
    },
    "3520": {
        "name": "Pharmaceuticals, Biotechnology & Life Sciences"
    },
    "4010": {
        "name": "Banks"
    },
    "4020": {
        "name": "Diversified Financials"
    },
    "4030": {
        "name": "Insurance"
    },
    "4040": {
        "name": "Real Estate"
    },
    "4510": {
        "name": "Software & Services"
    },
    "4520": {
        "name": "Technology Hardware & Equipment"
    },
    "4530": {
        "name": "Semiconductors & Semiconductor Equipment"
    },
    "5010": {
        "name": "Telecommunication Services"
    },
    "5510": {
        "name": "Utilities"
    },
    "101010": {
        "name": "Energy Equipment & Services"
    },
    "101020": {
        "name": "Oil, Gas & Consumable Fuels"
    },
    "151010": {
        "name": "Chemicals"
    },
    "151020": {
        "name": "Construction Materials"
    },
    "151030": {
        "name": "Containers & Packaging"
    },
    "151040": {
        "name": "Metals & Mining"
    },
    "151050": {
        "name": "Paper & Forest Products"
    },
    "201010": {
        "name": "Aerospace & Defense"
    },
    "201020": {
        "name": "Building Products"
    },
    "201030": {
        "name": "Construction & Engineering"
    },
    "201040": {
        "name": "Electrical Equipment"
    },
    "201050": {
        "name": "Industrial Conglomerates"
    },
    "201060": {
        "name": "Machinery"
    },
    "201070": {
        "name": "Trading Companies & Distributors"
    },
    "202010": {
        "name": "Commercial Services & Supplies"
    },
    "202020": {
        "name": "Professional Services"
    },
    "203010": {
        "name": "Air Freight & Logistics"
    },
    "203020": {
        "name": "Airlines"
    },
    "203030": {
        "name": "Marine"
    },
    "203040": {
        "name": "Road & Rail"
    },
    "203050": {
        "name": "Transportation Infrastructure"
    },
    "251010": {
        "name": "Auto Components"
    },
    "251020": {
        "name": "Automobiles"
    },
    "252010": {
        "name": "Household Durables"
    },
    "252020": {
        "name": "Leisure Products"
    },
    "252030": {
        "name": "Textiles, Apparel & Luxury Goods"
    },
    "253010": {
        "name": "Hotels, Restaurants & Leisure"
    },
    "253020": {
        "name": "Diversified Consumer Services"
    },
    "254010": {
        "name": "Media"
    },
    "255010": {
        "name": "Distributors"
    },
    "255020": {
        "name": "Internet & Catalog Retail"
    },
    "255030": {
        "name": "Multiline Retail"
    },
    "255040": {
        "name": "Specialty Retail"
    },
    "301010": {
        "name": "Food & Staples Retailing"
    },
    "302010": {
        "name": "Beverages"
    },
    "302020": {
        "name": "Food Products"
    },
    "302030": {
        "name": "Tobacco"
    },
    "303010": {
        "name": "Household Products"
    },
    "303020": {
        "name": "Personal Products"
    },
    "351010": {
        "name": "Health Care Equipment & Supplies"
    },
    "351020": {
        "name": "Health Care Providers & Services"
    },
    "351030": {
        "name": "Health Care Technology"
    },
    "352010": {
        "name": "Biotechnology"
    },
    "352020": {
        "name": "Pharmaceuticals"
    },
    "352030": {
        "name": "Life Sciences Tools & Services"
    },
    "401010": {
        "name": "Banks"
    },
    "401020": {
        "name": "Thrifts & Mortgage Finance"
    },
    "402010": {
        "name": "Diversified Financial Services"
    },
    "402020": {
        "name": "Consumer Finance"
    },
    "402030": {
        "name": "Capital Markets"
    },
    "403010": {
        "name": "Insurance"
    },
    "404010": {
        "name": "Real Estate -- Discontinued effective 04/28/2006"
    },
    "404020": {
        "name": "Real Estate Investment Trusts (REITs)"
    },
    "404030": {
        "name": "Real Estate Management & Development"
    },
    "451010": {
        "name": "Internet Software & Services"
    },
    "451020": {
        "name": "IT Services"
    },
    "451030": {
        "name": "Software"
    },
    "452010": {
        "name": "Communications Equipment"
    },
    "452020": {
        "name": "Technology Hardware, Storage & Peripherals"
    },
    "452030": {
        "name": "Electronic Equipment, Instruments & Components"
    },
    "452040": {
        "name": "Office Electronics - Discontinued effective 02/28/2014"
    },
    "452050": {
        "name": "Semiconductor Equipment & Products -- Discontinued effective 04/30/2003."
    },
    "453010": {
        "name": "Semiconductors & Semiconductor Equipment"
    },
    "501010": {
        "name": "Diversified Telecommunication Services"
    },
    "501020": {
        "name": "Wireless Telecommunication Services"
    },
    "551010": {
        "name": "Electric Utilities"
    },
    "551020": {
        "name": "Gas Utilities"
    },
    "551030": {
        "name": "Multi-Utilities"
    },
    "551040": {
        "name": "Water Utilities"
    },
    "551050": {
        "name": "Independent Power and Renewable Electricity Producers"
    },
    "10101010": {
        "name": "Oil & Gas Drilling",
        "description": "Drilling contractors or owners of drilling rigs that contract their services for drilling wells"
    },
    "10101020": {
        "name": "Oil & Gas Equipment & Services",
        "description": "Manufacturers of equipment, including drilling rigs and equipment, and providers of supplies and services to companies involved in the drilling, evaluation and completion of oil and gas wells."
    },
    "10102010": {
        "name": "Integrated Oil & Gas",
        "description": "Integrated oil companies engaged in the exploration & production of oil and gas, as well as at least one other significant activity in either refining, marketing and transportation, or chemicals."
    },
    "10102020": {
        "name": "Oil & Gas Exploration & Production",
        "description": "Companies engaged in the exploration and production of oil and gas not classified elsewhere."
    },
    "10102030": {
        "name": "Oil & Gas Refining & Marketing",
        "description": "Companies engaged in the refining and marketing of oil, gas and/or refined products not classified in the Integrated Oil & Gas or Independent Power Producers & Energy Traders Sub-Industries."
    },
    "10102040": {
        "name": "Oil & Gas Storage & Transportation",
        "description": "Companies engaged in the storage and/or transportation of oil, gas and/or refined products. Includes diversified midstream natural gas companies facing competitive markets, oil and refined product pipelines, coal slurry pipelines and oil & gas shipping companies."
    },
    "10102050": {
        "name": "Coal & Consumable Fuels",
        "description": "Companies primarily involved in the production and mining of coal, related products and other consumable fuels related to the generation of energy. Excludes companies primarily producing gases classified in the Industrial Gases sub-industry and companies primarily mining for metallurgical (coking) coal used for steel production."
    },
    "15101010": {
        "name": "Commodity Chemicals",
        "description": "Companies that primarily produce industrial chemicals and basic chemicals. Including but not limited to plastics, synthetic fibers, films, commodity-based paints & pigments, explosives and petrochemicals. Excludes chemical companies classified in the Diversified Chemicals, Fertilizers & Agricultural Chemicals, Industrial Gases, or Specialty Chemicals Sub-Industries."
    },
    "15101020": {
        "name": "Diversified Chemicals",
        "description": "Manufacturers of a diversified range of chemical products not classified in the Industrial Gases, Commodity Chemicals, Specialty Chemicals or Fertilizers & Agricultural Chemicals Sub-Industries."
    },
    "15101030": {
        "name": "Fertilizers & Agricultural Chemicals",
        "description": "Producers of fertilizers, pesticides, potash or other agriculture-related chemicals not classified elsewhere."
    },
    "15101040": {
        "name": "Industrial Gases",
        "description": "Manufacturers of industrial gases."
    },
    "15101050": {
        "name": "Specialty Chemicals",
        "description": "Companies that primarily produce high value-added chemicals used in the manufacture of a wide variety of products, including but not limited to fine chemicals, additives, advanced polymers, adhesives, sealants and specialty paints, pigments and coatings."
    },
    "15102010": {
        "name": "Construction Materials",
        "description": "Manufacturers of construction materials including sand, clay, gypsum, lime, aggregates, cement, concrete and bricks. Other finished or semi-finished building materials are classified in the Building Products Sub-Industry."
    },
    "15103010": {
        "name": "Metal & Glass Containers",
        "description": "Manufacturers of metal, glass or plastic containers. Includes corks and caps."
    },
    "15103020": {
        "name": "Paper Packaging",
        "description": "Manufacturers of paper and cardboard containers and packaging."
    },
    "15104010": {
        "name": "Aluminum",
        "description": "Producers of aluminum and related products, including companies that mine or process bauxite and companies that recycle aluminum to produce finished or semi-finished products. Excludes companies that primarily produce aluminum building materials classified in the Building Products Sub-Industry."
    },
    "15104020": {
        "name": "Diversified Metals & Mining",
        "description": "Companies engaged in the diversified production or extraction of metals and minerals not classified elsewhere. Including, but not limited to, nonferrous metal mining (except bauxite), salt and borate mining, phosphate rock mining, and diversified mining operations. Excludes iron ore mining, classified in the Steel Sub-Industry, bauxite mining, classified in the Aluminum Sub-Industry, and coal mining, classified in either the Steel or Coal & Consumable Fuels Sub-Industries."
    },
    "15104030": {
        "name": "Gold",
        "description": "Producers of gold and related products, including companies that mine or process gold and the South African finance houses which primarily invest in, but do not operate, gold mines."
    },
    "15104040": {
        "name": "Precious Metals & Minerals",
        "description": "Companies mining precious metals and minerals not classified in the Gold Sub-Industry. Includes companies primarily mining platinum."
    },
    "15104045": {
        "name": "Silver",
        "description": "Companies primarily mining silver. Excludes companies classified in the Gold or Precious Metals & Minerals Sub-Industries."
    },
    "15104050": {
        "name": "Steel",
        "description": "Producers of iron and steel and related products, including metallurgical (coking) coal mining used for steel production."
    },
    "15105010": {
        "name": "Forest Products",
        "description": "Manufacturers of timber and related wood products. Includes lumber for the building industry."
    },
    "15105020": {
        "name": "Paper Products",
        "description": "Manufacturers of all grades of paper. Excludes companies specializing in paper packaging classified in the Paper Packaging Sub-Industry."
    },
    "20101010": {
        "name": "Aerospace & Defense",
        "description": "Manufacturers of civil or military aerospace and defense equipment, parts or products. Includes defense electronics and space equipment."
    },
    "20102010": {
        "name": "Building Products",
        "description": "Manufacturers of building components and home improvement products and equipment. Excludes lumber and plywood classified under Forest Products and cement and other materials classified in the Construction Materials Sub-Industry."
    },
    "20103010": {
        "name": "Construction & Engineering",
        "description": "Companies engaged in primarily non-residential construction. Includes civil engineering companies and large-scale contractors. Excludes companies classified in the Homebuilding Sub-Industry."
    },
    "20104010": {
        "name": "Electrical Components & Equipment",
        "description": "Companies that produce electric cables and wires, electrical components or equipment not classified in the Heavy Electrical Equipment Sub-Industry."
    },
    "20104020": {
        "name": "Heavy Electrical Equipment",
        "description": "Manufacturers of power-generating equipment and other heavy electrical equipment, including power turbines, heavy electrical machinery intended for fixed-use and large electrical systems. Excludes cables and wires, classified in the Electrical Components & Equipment Sub-Industry."
    },
    "20105010": {
        "name": "Industrial Conglomerates",
        "description": "Diversified industrial companies with business activities in three or more sectors, none of which contributes a majority of revenues. Stakes held are predominantly of a controlling nature and stake holders maintain an operational interest in the running of the subsidiaries."
    },
    "20106010": {
        "name": "Construction Machinery & Heavy Trucks",
        "description": "Manufacturers of heavy duty trucks, rolling machinery, earth-moving and construction equipment, and manufacturers of related parts. Includes non-military shipbuilding."
    },
    "20106015": {
        "name": "Agricultural & Farm Machinery",
        "description": "Companies manufacturing agricultural machinery, farm machinery, and their related parts. Includes machinery used for the production of crops and agricultural livestock, agricultural tractors, planting and fertilizing machinery, fertilizer and chemical application equipment, and grain dryers and blowers."
    },
    "20106020": {
        "name": "Industrial Machinery",
        "description": "Manufacturers of industrial machinery and industrial components. Includes companies that manufacture presses, machine tools, compressors, pollution control equipment, elevators, escalators, insulators, pumps, roller bearings and other metal fabrications."
    },
    "20107010": {
        "name": "Trading Companies & Distributors",
        "description": "Trading companies and other distributors of industrial equipment and products."
    },
    "20201010": {
        "name": "Commercial Printing",
        "description": "Companies providing commercial printing services. Includes printers primarily serving the media industry."
    },
    "20201020": {
        "name": "Data Processing Services -- Discontinued effective 04/30/2003.",
        "description": "Providers of commercial electronic data processing services."
    },
    "20201030": {
        "name": "Diversified Commercial & Professional Services -- Discontinued effective 08/31/2008",
        "description": "Companies primarily providing commercial, industrial and professional services to businesses and governments not classified elsewhere. Includes commercial cleaning services, consulting services, correctional facilities, dining & catering services, document & communication services, equipment repair services, security & alarm services, storage & warehousing, and uniform rental services."
    },
    "20201040": {
        "name": "Human Resource & Employment Services -- Discontinued effective 08/31/2008",
        "description": "Companies providing business support services relating to human capital management. Includes employment agencies, employee training, payroll & benefit support services, retirement support services and temporary agencies."
    },
    "20201050": {
        "name": "Environmental & Facilities Services",
        "description": "Companies providing environmental and facilities maintenance services. Includes waste management, facilities management and pollution control services. Excludes large-scale water treatment systems classified in the Water Utilities Sub-Industry."
    },
    "20201060": {
        "name": "Office Services & Supplies",
        "description": "Providers of office services and manufacturers of office supplies and equipment not classified elsewhere."
    },
    "20201070": {
        "name": "Diversified Support Services",
        "description": "Companies primarily providing labor oriented support services to businesses and governments. Includes commercial cleaning services, dining & catering services, equipment repair services, industrial maintenance services, industrial auctioneers, storage & warehousing, transaction services, uniform rental services, and other business support services."
    },
    "20201080": {
        "name": "Security & Alarm Services",
        "description": "Companies providing security and protection services to business and governments. Includes companies providing services such as correctional facilities, security & alarm services, armored transportation & guarding. Excludes companies providing security software classified under the Systems Software Sub-Industry and home security services classified under the Specialized Consumer Services Sub-Industry. Also excludes companies manufacturing security system equipment classified under the Electronic Equipment & Instruments Sub-Industry. "
    },
    "20202010": {
        "name": "Human Resource & Employment Services",
        "description": "Companies providing business support services relating to human capital management. Includes employment agencies, employee training, payroll & benefit support services, retirement support services and temporary agencies."
    },
    "20202020": {
        "name": "Research & Consulting Services",
        "description": "Companies primarily providing research and consulting services to businesses and governments not classified elsewhere. Includes companies involved in management consulting services, architectural design, business information or scientific research, marketing, and testing & certification services. Excludes companies providing information technology consulting services classified in the IT Consulting & Other Services Sub-Industry."
    },
    "20301010": {
        "name": "Air Freight & Logistics",
        "description": "Companies providing air freight transportation, courier and logistics services, including package and mail delivery and customs agents. Excludes those companies classified in the Airlines, Marine or Trucking Sub-Industries."
    },
    "20302010": {
        "name": "Airlines",
        "description": "Companies providing primarily passenger air transportation."
    },
    "20303010": {
        "name": "Marine",
        "description": "Companies providing goods or passenger maritime transportation. Excludes cruise-ships classified in the Hotels, Resorts & Cruise Lines Sub-Industry."
    },
    "20304010": {
        "name": "Railroads",
        "description": "Companies providing primarily goods and passenger rail transportation."
    },
    "20304020": {
        "name": "Trucking",
        "description": "Companies providing primarily goods and passenger land transportation. Includes vehicle rental and taxi companies."
    },
    "20305010": {
        "name": "Airport Services",
        "description": "Operators of airports and companies providing related services."
    },
    "20305020": {
        "name": "Highways & Railtracks",
        "description": "Owners and operators of roads, tunnels and railtracks."
    },
    "20305030": {
        "name": "Marine Ports & Services",
        "description": "Owners and operators of marine ports and related services."
    },
    "25101010": {
        "name": "Auto Parts & Equipment",
        "description": "Manufacturers of parts and accessories for automobiles and motorcycles. Excludes companies classified in the Tires & Rubber Sub-Industry."
    },
    "25101020": {
        "name": "Tires & Rubber",
        "description": "Manufacturers of tires and rubber."
    },
    "25102010": {
        "name": "Automobile Manufacturers",
        "description": "Companies that produce mainly passenger automobiles and light trucks. Excludes companies producing mainly motorcycles and three-wheelers classified in the Motorcycle Manufacturers Sub-Industry and heavy duty trucks classified in the Construction Machinery & Heavy Trucks Sub-Industry."
    },
    "25102020": {
        "name": "Motorcycle Manufacturers",
        "description": "Companies that produce motorcycles, scooters or three-wheelers. Excludes bicycles classified in the Leisure Products Sub-Industry. "
    },
    "25201010": {
        "name": "Consumer Electronics",
        "description": "Manufacturers of consumer electronics products including TVs, home audio equipment, game consoles, digital cameras, and related products. Excludes personal home computer manufacturers classified in the Technology Hardware, Storage & Peripherals Sub-Industry, and electric household appliances classified in the Household Appliances Sub-Industry."
    },
    "25201020": {
        "name": "Home Furnishings",
        "description": "Manufacturers of soft home furnishings or furniture, including upholstery, carpets and wall-coverings."
    },
    "25201030": {
        "name": "Homebuilding",
        "description": "Residential construction companies. Includes manufacturers of prefabricated houses and semi-fixed manufactured homes."
    },
    "25201040": {
        "name": "Household Appliances",
        "description": "Manufacturers of electric household appliances and related products. Includes manufacturers of power and hand tools, including garden improvement tools. Excludes TVs and other audio and video products classified in the Consumer Electronics Sub-Industry and personal computers classified in the Technology Hardware, Storage & Peripherals Sub-Industry."
    },
    "25201050": {
        "name": "Housewares & Specialties",
        "description": "Manufacturers of durable household products, including cutlery, cookware, glassware, crystal, silverware, utensils, kitchenware and consumer specialties not classified elsewhere."
    },
    "25202010": {
        "name": "Leisure Products",
        "description": "Manufacturers of leisure products and equipment including sports equipment, bicycles and toys."
    },
    "25202020": {
        "name": "Photographic Products - Discontinued effective 02/28/2014",
        "description": "Manufacturers of photographic equipment and related products."
    },
    "25203010": {
        "name": "Apparel, Accessories & Luxury Goods",
        "description": "Manufacturers of apparel, accessories & luxury goods. Includes companies primarily producing designer handbags, wallets, luggage, jewelry and watches. Excludes shoes classified in the Footwear Sub-Industry."
    },
    "25203020": {
        "name": "Footwear",
        "description": "Manufacturers of footwear. Includes sport and leather shoes."
    },
    "25203030": {
        "name": "Textiles",
        "description": "Manufacturers of textile and related products not classified in the Apparel, Accessories & Luxury Goods, Footwear or Home Furnishings Sub-Industries."
    },
    "25301010": {
        "name": "Casinos & Gaming",
        "description": "Owners and operators of casinos and gaming facilities. Includes companies providing lottery and betting services."
    },
    "25301020": {
        "name": "Hotels, Resorts & Cruise Lines",
        "description": "Owners and operators of hotels, resorts and cruise-ships. Includes travel agencies, tour operators and related services not classified elsewhere . Excludes casino-hotels classified in the Casinos & Gaming Sub-Industry."
    },
    "25301030": {
        "name": "Leisure Facilities",
        "description": "Owners and operators of leisure facilities, including sport and fitness centers, stadiums, golf courses and amusement parks not classified in the Movies & Entertainment Sub-Industry."
    },
    "25301040": {
        "name": "Restaurants",
        "description": "Owners and operators of restaurants, bars, pubs, fast-food or take-out facilities. Includes companies that provide food catering services."
    },
    "25302010": {
        "name": "Education Services",
        "description": "Companies providing educational services, either on-line or through conventional teaching methods. Includes, private universities, correspondence teaching, providers of educational seminars, educational materials and technical education. Excludes companies providing employee education programs classified in the Human Resources & Employment Services Sub-Industry"
    },
    "25302020": {
        "name": "Specialized Consumer Services",
        "description": "Companies providing consumer services not classified elsewhere. Includes residential services, home security, legal services, personal services, renovation & interior design services, consumer auctions and wedding & funeral services."
    },
    "25401010": {
        "name": "Advertising",
        "description": "Companies providing advertising, marketing or public relations services."
    },
    "25401020": {
        "name": "Broadcasting",
        "description": "Owners and operators of television or radio broadcasting systems, including programming. Includes, radio and television broadcasting, radio networks, and radio stations."
    },
    "25401025": {
        "name": "Cable & Satellite",
        "description": "Providers of cable or satellite television services. Includes cable networks and program distribution."
    },
    "25401030": {
        "name": "Movies & Entertainment",
        "description": "Companies that engage in producing and selling entertainment products and services, including companies engaged in the production, distribution and screening of movies and television shows, producers and distributors of music, entertainment theaters and sports teams."
    },
    "25401040": {
        "name": "Publishing",
        "description": "Publishers of newspapers, magazines and books, and providers of information in print or electronic formats."
    },
    "25501010": {
        "name": "Distributors",
        "description": "Distributors and wholesalers of general merchandise not classified elsewhere. Includes vehicle distributors."
    },
    "25502010": {
        "name": "Catalog Retail",
        "description": "Mail order and TV home shopping retailers. Includes companies that provide door-to-door retail."
    },
    "25502020": {
        "name": "Internet Retail",
        "description": "Companies providing retail services primarily on the internet, not classified elsewhere."
    },
    "25503010": {
        "name": "Department Stores",
        "description": "Owners and operators of department stores."
    },
    "25503020": {
        "name": "General Merchandise Stores",
        "description": "Owners and operators of stores offering diversified general merchandise. Excludes hypermarkets and large-scale super centers classified in the Hypermarkets & Super Centers Sub-Industry."
    },
    "25504010": {
        "name": "Apparel Retail",
        "description": "Retailers specialized mainly in apparel and accessories."
    },
    "25504020": {
        "name": "Computer & Electronics Retail",
        "description": "Owners and operators of consumer electronics, computers, video and related products retail stores."
    },
    "25504030": {
        "name": "Home Improvement Retail",
        "description": "Owners and operators of home and garden improvement retail stores. Includes stores offering building materials and supplies."
    },
    "25504040": {
        "name": "Specialty Stores",
        "description": "Owners and operators of specialty retail stores not classified elsewhere. Includes jewelry stores, toy stores, office supply stores, health & vision care stores, and book & entertainment stores."
    },
    "25504050": {
        "name": "Automotive Retail",
        "description": "Owners and operators of stores specializing in automotive retail. Includes auto dealers, gas stations, and retailers of auto accessories, motorcycles & parts, automotive glass, and automotive equipment & parts."
    },
    "25504060": {
        "name": "Homefurnishing Retail",
        "description": "Owners and operators of furniture and home furnishings retail stores. Includes residential furniture, homefurnishings, housewares, and interior design. Excludes home and garden improvement stores, classified in the Home Improvement Retail Sub-Industry."
    },
    "30101010": {
        "name": "Drug Retail",
        "description": "Owners and operators of primarily drug retail stores and pharmacies."
    },
    "30101020": {
        "name": "Food Distributors",
        "description": "Distributors of food products to other companies and not directly to the consumer."
    },
    "30101030": {
        "name": "Food Retail",
        "description": "Owners and operators of primarily food retail stores."
    },
    "30101040": {
        "name": "Hypermarkets & Super Centers",
        "description": "Owners and operators of hypermarkets and super centers selling food and a wide-range of consumer staple products. Excludes Food and Drug Retailers classified in the Food Retail and Drug Retail Sub-Industries, respectively."
    },
    "30201010": {
        "name": "Brewers",
        "description": "Producers of beer and malt liquors. Includes breweries not classified in the Restaurants Sub-Industry."
    },
    "30201020": {
        "name": "Distillers & Vintners",
        "description": "Distillers, vintners and producers of alcoholic beverages not classified in the Brewers Sub-Industry."
    },
    "30201030": {
        "name": "Soft Drinks",
        "description": "Producers of non-alcoholic beverages including mineral waters. Excludes producers of milk classified in the Packaged Foods Sub-Industry."
    },
    "30202010": {
        "name": "Agricultural Products",
        "description": "Producers of agricultural products. Includes crop growers, owners of plantations and companies that produce and process foods but do not package and market them. Excludes companies classified in the Forest Products Sub-Industry and those that package and market the food products classified in the Packaged Foods Sub-Industry."
    },
    "30202020": {
        "name": "Meat, Poultry & Fish (discontinued, effective March 28 2002)",
        "description": "Companies that raise livestock or poultry, fishing companies and other producers of meat, poultry or fish products."
    },
    "30202030": {
        "name": "Packaged Foods & Meats",
        "description": "Producers of packaged foods including dairy products, fruit juices, meats, poultry, fish and pet foods."
    },
    "30203010": {
        "name": "Tobacco",
        "description": "Manufacturers of cigarettes and other tobacco products."
    },
    "30301010": {
        "name": "Household Products",
        "description": "Producers of non-durable household products, including detergents, soaps, diapers and other tissue and household paper products not classified in the Paper Products Sub-Industry."
    },
    "30302010": {
        "name": "Personal Products",
        "description": "Manufacturers of personal and beauty care products, including cosmetics and perfumes."
    },
    "35101010": {
        "name": "Health Care Equipment",
        "description": "Manufacturers of health care equipment and devices. Includes medical instruments, drug delivery systems, cardiovascular & orthopedic devices, and diagnostic equipment."
    },
    "35101020": {
        "name": "Health Care Supplies",
        "description": "Manufacturers of health care supplies and medical products not classified elsewhere. Includes eye care products, hospital supplies, and safety needle & syringe devices."
    },
    "35102010": {
        "name": "Health Care Distributors",
        "description": "Distributors and wholesalers of health care products not classified elsewhere. "
    },
    "35102015": {
        "name": "Health Care Services",
        "description": "Providers of patient health care services not classified elsewhere. Includes dialysis centers, lab testing services, and pharmacy management services. Also includes companies providing business support services to health care providers, such as clerical support services, collection agency services, staffing services and outsourced sales & marketing services"
    },
    "35102020": {
        "name": "Health Care Facilities",
        "description": "Owners and operators of health care facilities, including hospitals, nursing homes, rehabilitation centers and animal hospitals."
    },
    "35102030": {
        "name": "Managed Health Care",
        "description": "Owners and operators of Health Maintenance Organizations (HMOs) and other managed plans."
    },
    "35103010": {
        "name": "Health Care Technology",
        "description": "Companies providing information technology services primarily to health care providers. Includes companies providing application, systems and/or data processing software, internet-based tools, and IT consulting services to doctors, hospitals or businesses operating primarily in the Health Care Sector"
    },
    "35201010": {
        "name": "Biotechnology",
        "description": "Companies primarily engaged in the research, development, manufacturing and/or marketing of products based on genetic analysis and genetic engineering. Includes companies specializing in protein-based therapeutics to treat human diseases. Excludes companies manufacturing products using biotechnology but without a health care application."
    },
    "35202010": {
        "name": "Pharmaceuticals",
        "description": "Companies engaged in the research, development or production of pharmaceuticals. Includes veterinary drugs."
    },
    "35203010": {
        "name": "Life Sciences Tools & Services",
        "description": "Companies enabling the drug discovery, development and production continuum by providing analytical tools, instruments, consumables & supplies, clinical trial services and contract research services. Includes firms primarily servicing the pharmaceutical and biotechnology industries."
    },
    "40101010": {
        "name": "Diversified Banks",
        "description": "Large, geographically diverse banks with a national footprint whose revenues are derived primarily from conventional banking operations, have significant business activity in retail banking and small and medium corporate lending, and provide a diverse range of financial services. Excludes banks classified in the Regional Banks and Thrifts & Mortgage Finance Sub-Industries. Also excludes investment banks classified in the Investment Banking & Brokerage Sub-Industry."
    },
    "40101015": {
        "name": "Regional Banks",
        "description": "Commercial banks whose businesses are derived primarily from conventional banking operations and have significant business activity in retail banking and small and medium corporate lending. Regional banks tend to operate in limited geographic regions. Excludes companies classified in the Diversified Banks and Thrifts & Mortgage Banks sub-industries. Also excludes investment banks classified in the Investment Banking & Brokerage Sub-Industry."
    },
    "40102010": {
        "name": "Thrifts & Mortgage Finance",
        "description": "Financial institutions providing mortgage and mortgage related services. These include financial institutions whose assets are primarily mortgage related, savings & loans, mortgage lending institutions, building societies and companies providing insurance to mortgage banks."
    },
    "40201010": {
        "name": "Consumer Finance -- Discontinued effective 04/30/2003.",
        "description": "Providers of consumer finance services, including personal credit, credit cards, lease financing, mortgage lenders, travel-related money services and pawn shops."
    },
    "40201020": {
        "name": "Other Diversified Financial Services",
        "description": "Providers of a diverse range of financial services and/or with some interest in a wide range of financial services including banking, insurance and capital markets, but with no dominant business line. Excludes companies classified in the Regional Banks and Diversified Banks Sub-Industries."
    },
    "40201030": {
        "name": "Multi-Sector Holdings",
        "description": "A company with significantly diversified holdings across three or more sectors, none of which contributes a majority of profit and/or sales. Stakes held are predominantly of a non-controlling nature. Includes diversified financial companies where stakes held are of a controlling nature. Excludes other diversified companies classified in the Industrials Conglomerates Sub-Industry."
    },
    "40201040": {
        "name": "Specialized Finance",
        "description": "Providers of specialized financial services. Includes credit agencies, stock exchanges and specialty boutiques. Companies in this Sub-Industry derive a majority of revenue from one, specialized line of business."
    },
    "40202010": {
        "name": "Consumer Finance",
        "description": "Providers of consumer finance services, including personal credit, credit cards, lease financing, travel-related money services and pawn shops. Excludes mortgage lenders classified in the Thrifts & Mortgage Finance Sub-Industry."
    },
    "40203010": {
        "name": "Asset Management & Custody Banks",
        "description": "Financial institutions primarily engaged in investment management and/or related custody and securities fee-based services. Includes companies operating mutual funds, closed-end funds and unit investment trusts. Excludes banks and other financial institutions primarily involved in commercial lending, investment banking, brokerage and other specialized financial activities. "
    },
    "40203020": {
        "name": "Investment Banking & Brokerage",
        "description": "Financial institutions primarily engaged in investment banking & brokerage services, including equity and debt underwriting, mergers and acquisitions, securities lending and advisory services. Excludes banks and other financial institutions primarily involved in commercial lending, asset management and specialized financial activities. "
    },
    "40203030": {
        "name": "Diversified Capital Markets",
        "description": "Financial institutions primarily engaged in diversified capital markets activities, including a significant presence in at least two of the following area: large/major corporate lending, investment banking, brokerage and asset management. Excludes less diversified companies classified in the Asset Management & Custody Banks or Investment Banking & Brokerage sub-industries. Also excludes companies classified in the Banks or Insurance industry groups or the Consumer Finance Sub-Industry. "
    },
    "40301010": {
        "name": "Insurance Brokers",
        "description": "Insurance and reinsurance brokerage firms."
    },
    "40301020": {
        "name": "Life & Health Insurance",
        "description": "Companies providing primarily life, disability, indemnity or supplemental health insurance. Excludes managed care companies classified in the Managed Health Care Sub-Industry."
    },
    "40301030": {
        "name": "Multi-line Insurance",
        "description": "Insurance companies with diversified interests in life, health and property and casualty insurance."
    },
    "40301040": {
        "name": "Property & Casualty Insurance",
        "description": "Companies providing primarily property and casualty insurance."
    },
    "40301050": {
        "name": "Reinsurance",
        "description": "Companies providing primarily reinsurance."
    },
    "40401010": {
        "name": "Real Estate Investment Trusts -- Discontinued effective 04/28/2006",
        "description": "Real estate investment trusts (REITs). Includes Property Trusts."
    },
    "40401020": {
        "name": "Real Estate Management & Development -- Discontinued effective 04/28/2006",
        "description": "Companies engaged in real estate ownership, development or management."
    },
    "40402010": {
        "name": "Diversified REITs",
        "description": "A company or Trust with significantly diversified operations across two or more property types."
    },
    "40402020": {
        "name": "Industrial REITs",
        "description": "Companies or Trusts engaged in the acquisition, development, ownership, leasing, management and operation of industrial properties. Includes companies operating industrial warehouses and distribution properties."
    },
    "40402030": {
        "name": "Mortgage REITs",
        "description": "Companies or Trusts that service, originate, purchase and/or securitize residential and/or commercial mortgage loans. Includes trusts that invest in mortgage-backed securities and other mortgage related assets."
    },
    "40402035": {
        "name": "Hotel & Resort REITs",
        "description": "Companies or Trusts engaged in the acquisition, development, ownership, leasing, management and operation of hotel and resort properties. "
    },
    "40402040": {
        "name": "Office REITs",
        "description": "Companies or Trusts engaged in the acquisition, development, ownership, leasing, management and operation of office properties."
    },
    "40402045": {
        "name": "Health Care REITs",
        "description": "Companies or Trusts engaged in the acquisition, development, ownership, leasing, management and operation of properties serving the health care industry, including hospitals, nursing homes, and assisted living properties."
    },
    "40402050": {
        "name": "Residential REITs",
        "description": "Companies or Trusts engaged in the acquisition, development, ownership, leasing, management and operation of residential properties including multifamily homes, apartments, manufactured homes and student housing properties"
    },
    "40402060": {
        "name": "Retail REITs",
        "description": "Companies or Trusts engaged in the acquisition, development, ownership, leasing, management and operation of shopping malls, outlet malls, neighborhood and community shopping centers."
    },
    "40402070": {
        "name": "Specialized REITs",
        "description": "Companies or Trusts engaged in the acquisition, development, ownership, leasing, management and operation of properties not classified elsewhere. Includes trusts that operate and invest in storage properties. It also includes REITs that do not generate a majority of their revenues and income from real estate rental and leasing operations."
    },
    "40403010": {
        "name": "Diversified Real Estate Activities",
        "description": "Companies engaged in a diverse spectrum of real estate activities including real estate development & sales, real estate management, or real estate services, but with no dominant business line."
    },
    "40403020": {
        "name": "Real Estate Operating Companies",
        "description": "Companies engaged in operating real estate properties for the purpose of leasing & management."
    },
    "40403030": {
        "name": "Real Estate Development",
        "description": "Companies that develop real estate and sell the properties after development. Excludes companies classified in the Homebuilding Sub-Industry."
    },
    "40403040": {
        "name": "Real Estate Services",
        "description": "Real estate service providers such as real estate agents, brokers & real estate appraisers."
    },
    "45101010": {
        "name": "Internet Software & Services",
        "description": "Companies developing and marketing internet software and/or providing internet services including online databases and interactive services, as well as companies deriving a majority of their revenues from online advertising. Excludes companies classified in the Internet Retail Sub-Industry."
    },
    "45102010": {
        "name": "IT Consulting & Other Services",
        "description": "Providers of information technology and systems integration services not classified in the Data Processing & Outsourced Services or Internet Software & Services Sub-Industries. Includes information technology consulting and information management services."
    },
    "45102020": {
        "name": "Data Processing & Outsourced Services",
        "description": "Providers of commercial electronic data processing and/or business process outsourcing services. Includes companies that provide services for back-office automation."
    },
    "45103010": {
        "name": "Application Software",
        "description": "Companies engaged in developing and producing software designed for specialized applications for the business or consumer market. Includes enterprise and technical software. Excludes companies classified in the Home Entertainment Software Sub-Industry. Also excludes companies producing systems or database management software classified in the Systems Software Sub-Industry."
    },
    "45103020": {
        "name": "Systems Software",
        "description": "Companies engaged in developing and producing systems and database management software."
    },
    "45103030": {
        "name": "Home Entertainment Software",
        "description": "Manufacturers of home entertainment software and educational software used primarily in the home."
    },
    "45201010": {
        "name": "Networking Equipment -- Discontinued effective 04/30/2003.",
        "description": "Manufacturers of computer networking equipment and products, including LANs, WANs and routers."
    },
    "45201020": {
        "name": "Telecommunications Equipment -- Discontinued effective 04/30/2003.",
        "description": "Manufacturers of telecommunication equipment, including telephones, switchboards and exchanges. Excludes companies classified in the Networking Equipment Sub-Industry."
    },
    "45202010": {
        "name": "Computer Hardware - Discontinued effective 02/28/2014",
        "description": "Manufacturers of personal computers, servers, mainframes and workstations. Includes manufacturers of Automatic Teller Machines (ATMs). Excludes manufacturers of copiers, faxes and related products classified in the Office Electronics Sub-Industry."
    },
    "45202020": {
        "name": "Computer Storage & Peripherals - Discontinued effective 02/28/2014",
        "description": "Manufacturers of electronic computer components and peripherals. Includes data storage components, motherboards, audio and video cards, monitors, keyboards, printers and other peripherals. Excludes semiconductors classified in the Semiconductors Sub-Industry."
    },
    "45202030": {
        "name": "Technology Hardware, Storage & Peripherals",
        "description": "Manufacturers of cellular phones, personal computers, servers, electronic computer components and peripherals. Includes data storage components, motherboards, audio and video cards, monitors, keyboards, printers, and other peripherals. Excludes semiconductors classified in the Semiconductors Sub-Industry."
    },
    "45203010": {
        "name": "Electronic Equipment & Instruments ",
        "description": "Manufacturers of electronic equipment and instruments including analytical, electronic test and measurement instruments, scanner/barcode products, lasers, display screens, point-of-sales machines, and security system equipment."
    },
    "45203015": {
        "name": "Electronic Components",
        "description": "Manufacturers of electronic components. Includes electronic components, connection devices, electron tubes, electronic capacitors and resistors, electronic coil, printed circuit board, transformer and other inductors, signal processing technology/components."
    },
    "45203020": {
        "name": "Electronic Manufacturing Services",
        "description": "Producers of electronic equipment mainly for the OEM (Original Equipment Manufacturers) markets."
    },
    "45203030": {
        "name": "Technology Distributors",
        "description": "Distributors of technology hardware and equipment. Includes distributors of communications equipment, computers & peripherals, semiconductors, and electronic equipment and components."
    },
    "45204010": {
        "name": "Office Electronics - Discontinued effective 02/28/2014",
        "description": "Manufacturers of office electronic equipment including copiers and faxes."
    },
    "45205010": {
        "name": "Semiconductor Equipment -- Discontinued effective 04/30/2003.",
        "description": "Manufacturers of semiconductor equipment."
    },
    "45205020": {
        "name": "Semiconductors -- Discontinued effective 04/30/2003.",
        "description": "Manufacturers of semiconductors and related products."
    },
    "45301010": {
        "name": "Semiconductor Equipment ",
        "description": "Manufacturers of semiconductor equipment, including manufacturers of the raw material and equipment used in the solar power industry."
    },
    "45301020": {
        "name": "Semiconductors",
        "description": "Manufacturers of semiconductors and related products, including manufacturers of solar modules and cells."
    },
    "50101010": {
        "name": "Alternative Carriers",
        "description": "Providers of communications and high-density data transmission services primarily through a high bandwidth/fiber-optic cable network."
    },
    "50101020": {
        "name": "Integrated Telecommunication Services",
        "description": "Operators of primarily fixed-line telecommunications networks and companies providing both wireless and fixed-line telecommunications services not classified elsewhere."
    },
    "50102010": {
        "name": "Wireless Telecommunication Services",
        "description": "Providers of primarily cellular or wireless telecommunication services, including paging services."
    },
    "55101010": {
        "name": "Electric Utilities",
        "description": "Companies that produce or distribute electricity. Includes both nuclear and non-nuclear facilities."
    },
    "55102010": {
        "name": "Gas Utilities",
        "description": "Companies whose main charter is to distribute and transmit natural and manufactured gas. Excludes companies primarily involved in gas exploration or production classified in the Oil & Gas Exploration & Production Sub-Industry. Also excludes diversified midstream natural gas companies classified in the Oil & Gas Storage & Transportation Sub-Industry."
    },
    "55103010": {
        "name": "Multi-Utilities",
        "description": "Utility companies with significantly diversified activities in addition to core Electric Utility, Gas Utility and/or Water Utility operations."
    },
    "55104010": {
        "name": "Water Utilities",
        "description": "Companies that purchase and redistribute water to the end-consumer. Includes large-scale water treatment systems."
    },
    "55105010": {
        "name": "Independent Power Producers & Energy Traders",
        "description": "Companies that operate as Independent Power Producers (IPPs), Gas & Power Marketing & Trading Specialists and/or Integrated Energy Merchants. Excludes producers of electricity using renewable sources, such as solar power, hydropower, and wind power. Also excludes electric transmission companies and utility distribution companies classified in the Electric Utilities Sub-Industry."
    },
    "55105020": {
        "name": "Renewable Electricity ",
        "description": "Companies that engage in the generation and distribution of electricity using renewable sources, including, but not limited to, companies that produce electricity using biomass, geothermal energy, solar energy, hydropower, and wind power. Excludes companies manufacturing capital equipment used to generate electricity using renewable sources, such as manufacturers of solar power systems, installers of photovoltaic cells, and companies involved in the provision of technology, components, and services mainly to this market. "
    }
}
